==> playvideo-1.5.zip: playvideo-1.5/plugin/playvideo.inc.pl <==
############################################################
# playvideo plugin
# playvideo.inc.pl
# Copyright(c) 2011 Nanami.
# for PyukiWiki 0.1.7 (http://pyukiwiki.sourceforge.jp/)
#
# 2011/03/14 change: Content-disposition: attachment; filename="$file.wvx"
#                    Ϥ꤬ǽ뤿ᡢϤ
#                    
# 2011/03/01 change: ĥҤwvxѹ
#                    Content-Type: video/x-ms-wvx Ϥ
#                    Content-disposition: attachment; filename="$file.wvx"
#                    Ϥ
# 2010/12/10 change: ˥˥ưб
#                    ĥҤwmxѹ
# 2010/11/13 change: ̵zipǥɤǤ褦ˤ
#                    ̤ư褬Ȥå夫褦
#                    ͭ¤ϣ֤Ǥ
# 2010/10/27 change: MSIE OperaʳWindwos Mediaץ쥤䡼
#                    _blank(¼̥֡ˤˤʤ褦ˤ
#                    SafariǤˤʤޤ
# 2010/10/24 change: use sub make_link_target
#
# 1TAB=4Spaces

use Nana::Cache;
use Image::ExifTool;
require "plugin/counter.inc.pl";

$playvideo_plugin_usedownload=1;	# Ȥʤ0ˤ롣
$playvideo_plugin_zipcmds=<<EOM;
/usr/bin/zip
/usr/local/bin/zip
EOM
$playvideo_plugin_zipflags="-0";
$playvideo_plugin_ziptmp="/tmp";
$playvideo_plugin_videopath="video";
$playvideo_plugin_playsite="http://$ENV{HTTP_HOST}/v.cgi";
$playvideo_plugin_videourl="http://$ENV{HTTP_HOST}/$videopath";

sub plugin_playvideo_inline {
	my ($arg)=@_;
	my ($fname,$youtube,$nicovideo)=split(/,/,$arg);
	my $body;

	$videopath=$playvideo_plugin_videopath;
	$playsite=$playvideo_plugin_playsite;
	$videourl=$playvideo_plugin_videourl;
	$fname=~s/\..*//g;
	$wmv="wmv";
	$ext="wvx";
	$zip="zip";

	my $browser=$ENV{HTTP_USER_AGENT};
	my $wmvtarget = "";
	if ($browser=~/MSIE/ || $browser=~/Opera/ ) { 
	} else {
		$wmvtarget = "_blank";
	}
	$body.=<<EOM;
<strong>
@{[&make_link_target("$playsite/$fname.$ext","",$wmvtarget,"Windows Media PlayerǺ")]}
[Windows Media PlayerǺ]</a></strong>
EOM
	if($youtube ne '') {
		$body.=<<EOM;
@{[&make_link_target("$playsite/$fname.$youtube","","_blank","YoutubeǺ")]}
[YoutubeǺ]</a>
EOM
	}

	if($nicovideo ne '') {
		$body.=<<EOM;
@{[&make_link_target("$playsite/$fname.$nicovideo","","_blank","˥˥ưǺ")]}
[˥˥ưǺ]</a>
EOM
	}
	if($playvideo_plugin_usedownload eq 1) {

		$body.=<<EOM;
@{[&make_link_target("$playsite/$fname.$zip","","","")]}
[]</a>
EOM
	}

	my $cache=new Nana::Cache (
		ext=>"playvideo",
		files=>500,
		dir=>$::cache_dir,
		size=>100000,
		use=>1,
		expire=>3600
	);
	my $cachefile="playvideo_$fname";
	my $buf=$cache->read($cachefile,1);
	if($buf eq '') {
		my $exifTool = new Image::ExifTool;
		my $info = $exifTool->ImageInfo("$videopath/$fname.$wmv");
		my $title=&Jcode::convert($$info{Title}, 'sjis', 'utf8');
		my $author=&Jcode::convert($$info{Author}, 'sjis', 'utf8');
		my $copyright=&Jcode::convert($$info{Copyright}, 'sjis', 'utf8');
		$buf=<<EOM;
$$info{SendDuration},$title,$author,$copyright
EOM
		$cache->write($cachefile,$buf);
	}
	my ($time,$title,$author,$copyright)=split(/,/,$buf);
	$body.=<<EOM;
($time)
<br>
EOM
	%vcounter=&plugin_counter_do("playvideo_$fname","r");
	$body.=<<EOM;
<span style="font-size: 10px;">
TOTAL: $vcounter{total} TODAY: $vcounter{today} YESTERDAY:$vcounter{yesterday}
</span>
EOM

	return $body;
}
1;

==> playvideo-1.6.zip: playvideo-1.6/plugin/playvideo.inc.pl <==
############################################################
# playvideo plugin
# playvideo.inc.pl
# Copyright(c) 2011 Nanami.
# for PyukiWiki 0.1.7 (http://nanakochi.daiba.cx/)
#
# 2011/05/26 change: wmv˥դƤ硢zipեΥ
#                    ե̾򤽤̾˻Ǥ褦ˤ
# 2011/05/26 change: info/setup.cgiб
# 2011/03/14 change: Content-disposition: attachment; filename="$file.wvx"
#                    Ϥ꤬ǽ뤿ᡢϤ
#                    
# 2011/03/01 change: ĥҤwvxѹ
#                    Content-Type: video/x-ms-wvx Ϥ
#                    Content-disposition: attachment; filename="$file.wvx"
#                    Ϥ
# 2010/12/10 change: ˥˥ưб
# 2010/12/10 change: ˥˥ưб
# 2010/11/13 change: ̵zipǥɤǤ褦ˤ
#                    ̤ư褬Ȥå夫褦
#                    ͭ¤ϣ֤Ǥ
# 2010/10/27 change: MSIE OperaʳWindwos Mediaץ쥤䡼
#                    _blank(¼̥֡ˤˤʤ褦ˤ
#                    SafariǤˤʤޤ
# 2010/10/24 change: use sub make_link_target
#
# 1TAB=4Spaces

use Nana::Cache;
use Image::ExifTool;
require "plugin/counter.inc.pl";

$::playvideo_plugin_usedownload=1		# Ȥʤ0ˤ롣
	if(!defined($::playvideo_plugin_usedownload));
$::playvideo_plugin_zipflags="-0";
$::playvideo_plugin_ziptmp="/tmp"
	if(!defined($::playvideo_plugin_ziptmp));
$::playvideo_plugin_videopath="video"
	if(!defined($::playvideo_plugin_videopath));
$::playvideo_plugin_playsite="http://$ENV{HTTP_HOST}/v.cgi"
	if(!defined($::playvideo_plugin_playsite));
$::playvideo_plugin_videourl="http://$ENV{HTTP_HOST}/$videopath"
	if(!defined($::playvideo_plugin_videourl));
# wmvΥȥzip
$::playvideo_plugin_downloadfilename_inwmv=0
	if(!defined($::playvideo_plugin_downloadfilename_inwmv));
# wmvκԤzip
$::playvideo_plugin_downloadfilename_inwmv_withauthor=0
	if(!defined($::playvideo_plugin_downloadfilename_inwmv_withauthor));

$playvideo_plugin_zipcmds=<<EOM;
/usr/bin/zip
/usr/local/bin/zip
EOM

sub plugin_playvideo_inline {
	my ($arg)=@_;
	my ($fname,$youtube,$nicovideo)=split(/,/,$arg);
	my $body;

	$videopath=$playvideo_plugin_videopath;
	$playsite=$playvideo_plugin_playsite;
	$videourl=$playvideo_plugin_videourl;
	$fname=~s/\..*//g;
	$wmv="wmv";
	$ext="wvx";
	$zip="zip";

	my $browser=$ENV{HTTP_USER_AGENT};
	my $wmvtarget = "";
	if ($browser=~/MSIE/ || $browser=~/Opera/ ) { 
	} else {
		$wmvtarget = "_blank";
	}
	$body.=<<EOM;
<strong>
@{[&make_link_target("$playsite/$fname.$ext","",$wmvtarget,"Windows Media PlayerǺ")]}
[Windows Media PlayerǺ]</a></strong>
EOM
	if($youtube ne '') {
		$body.=<<EOM;
@{[&make_link_target("$playsite/$fname.$youtube","","_blank","YoutubeǺ")]}
[YoutubeǺ]</a>
EOM
	}

	if($nicovideo ne '') {
		$body.=<<EOM;
@{[&make_link_target("$playsite/$fname.$nicovideo","","_blank","˥˥ưǺ")]}
[˥˥ưǺ]</a>
EOM
	}
	if($playvideo_plugin_usedownload eq 1) {

		$body.=<<EOM;
@{[&make_link_target("$playsite/$fname.$zip","","","")]}
[]</a>
EOM
	}

	my $cache=new Nana::Cache (
		ext=>"playvideo",
		files=>500,
		dir=>$::cache_dir,
		size=>100000,
		use=>1,
		expire=>1000000000000000
	);
	my $cachefile="playvideo_$fname";
	my $buf=$cache->read($cachefile,1);
	if($buf eq '') {
		my $exifTool = new Image::ExifTool;
		my $info = $exifTool->ImageInfo("$videopath/$fname.$wmv");
		my $title=&Jcode::convert($$info{Title}, 'sjis', 'utf8');
		my $author=&Jcode::convert($$info{Author}, 'sjis', 'utf8');
		my $copyright=&Jcode::convert($$info{Copyright}, 'sjis', 'utf8');
		$buf=<<EOM;
$$info{SendDuration},$title,$author,$copyright
EOM
		$cache->write($cachefile,$buf);
	}
	my ($time,$title,$author,$copyright)=split(/,/,$buf);
	$body.=<<EOM;
($time)
<br>
EOM
	%vcounter=&plugin_counter_do("playvideo_$fname","r");
	$body.=<<EOM;
<span style="font-size: 10px;">
TOTAL: $vcounter{total} TODAY: $vcounter{today} YESTERDAY:$vcounter{yesterday}
</span>
EOM

	return $body;
}
1;
